Crate maincopy_shared

Crate maincopy_shared 

Wire contracts shared by Maincopy’s server and operator client.

Modules

auth
Wire-safe identity and authorization contracts for the private admin plane.
auth_api
Stable wire contracts for admin login and browser sessions.
posts
Wire contracts for listing posts loaded by the content compiler.
profile
Validated public profile values shared by the admin server and its clients.
profile_api
Versioned wire contracts for profile-backed Lightning tip settings.
publication
Wire contracts for approving exact post revisions for publication.
source
Validated managed-source values and versioned source-sync wire contracts.

Structs

AdminApiCapabilities
Version-neutral discovery contract for one running Maincopy server.
Capabilities
Contract versions supported by one running Maincopy server.
FeatureVersions
Versions of the currently advertised admin features.
SupportedFeatureContracts
Feature contract versions supported by one running Maincopy server.

Enums

AdminApiVersion
Admin API versions understood by this contract crate.
CapabilityContractVersion
Versions of the capabilities response contract.

Constants

ADMIN_CAPABILITIES_PATH
Stable path for discovering the private admin contracts supported by a server.
CAPABILITIES_PATH
Versioned path for discovering the V1 private admin contract.