Module auth

Module auth 

Wire-safe identity and authorization contracts for the private admin plane.

Structs

AdminAuditEventId
AdminSessionId
AgentCredentialId
InstanceId
LoginChallengeId
UserId

Enums

AdminScope
One independently enforced authority in the private admin plane.
HumanLoginProvider
Configurable provider used to authenticate a human user.
UserRole
A built-in bundle of fixed admin scopes.
UserStatus
Whether a human account can authenticate and exercise its assigned roles.

Functions

effective_scopes
Returns the union of the immutable scope bundles for a user’s roles.