pub fn effective_scopes(
roles: impl IntoIterator<Item = UserRole>,
) -> BTreeSet<AdminScope>Expand description
Returns the union of the immutable scope bundles for a user’s roles.
pub fn effective_scopes(
roles: impl IntoIterator<Item = UserRole>,
) -> BTreeSet<AdminScope>Returns the union of the immutable scope bundles for a user’s roles.