pub enum CreateAdminSessionRequest {
Password {
username: Box<str>,
password: SecretString,
},
Nostr {
challenge_id: LoginChallengeId,
challenge: SecretString,
event: Box<str>,
},
}Expand description
A human proof that can create one opaque server-side browser session.
This type intentionally has no Debug implementation because the password
variant contains a raw secret.
Variants