Module posts

Module posts 

Wire contracts for listing posts loaded by the content compiler.

Structs

ListPostsResponse
One cursor-paginated page of posts from an immutable site revision.
PostSummary
Summary of one post revision loaded from the Git-owned content tree.

Enums

PostPublicationState
Canonical publication state of one loaded post revision.

Constants

POSTS_PATH
Versioned path for listing loaded post revisions.