Module profile

Module profile 

Validated public profile values shared by the admin server and its clients.

Structs

LightningAddress
A canonical clearnet LUD-16 internet identifier.
ProfileDisplayName
A bounded, visible profile name preserved exactly as entered.
ProfileVersion
A positive profile resource version representable by SQLite.

Enums

LightningAddressError
ProfileDisplayNameError
ProfileVersionError

Constants

MAX_LIGHTNING_ADDRESS_BYTES
MAX_PROFILE_DISPLAY_NAME_BYTES