Module profile_api

Module profile_api 

Versioned wire contracts for profile-backed Lightning tip settings.

Structs

ActiveTipRecipientResponse
The versioned site setting selecting the only active tip recipient.
PutActiveTipRecipientRequest
Selects or clears the active site tip recipient at one exact setting version.
UpdateUserProfileRequest
Creates or replaces the authenticated user’s mutable public profile.
UserProfileResponse
The authenticated user’s mutable public profile.

Constants

ACTIVE_TIP_RECIPIENT_PATH
CURRENT_USER_PROFILE_PATH